@@ -40,11 +40,16 @@ class AuthMiddleware:
                 pack = self.client.full_fetch(ref)
 
                 self.client.sessions[ref] = {'pending': False, 'revalidated': False, **pack['azp']}
-                response = HTMLResponse(
-                    '<!DOCTYPE html><html lang="en">'
-                    '<head><meta charset="UTF-8"><title>Authorized</title></head>'
-                    '<body>Good auth.<script>window.close()</script></body>'
-                    '</html>')
+                # language=html
+                callback_html = """
+                <!DOCTYPE html><html lang="en">
+                <head><meta charset="UTF-8"><title>Authorized</title></head>
+                <body>Good auth.<script>window.close()</script></body>
+                </html>
+                """
+
+                response = HTMLResponse(callback_html, status_code=200)
+
                 if self.client.sessions[ref]['user_id']:
                     response.set_cookie(key='user_id', value=self.client.sessions[ref]['user_id'], samesite='none',
                                         secure=True, expires=2147483647)
@@ -62,31 +67,34 @@ class AuthMiddleware:
                 await resp(scope, receive, send)
 
             elif path.startswith('/bsAuth/logout'):
+                print(request)
+
                 # language=html
                 page_html = """
-                    <html lang='en-us'>
-                        <head><title>Logged Out</title></head>
-                        <body>
+                    <!DOCTYPE html><html lang='en-us'>
+                    <head><title>Logged Out</title></head>
+                    <body>
                         <div><p>
                             Logout successful. 
                             Redirecting in <span id='countdown'>3</span> seconds. 
                             Click <a href='/'>here</a> to jump immediately.
                         </p></div>
+                        
                         <script>
-                        const elem = document.getElementById('countdown');
-                        const updateOrJump = () => {
-                            let curTime = Number(elem.innerText);
-                            if (curTime > 0) {
-                                curTime--;
-                                elem.innerText = String(curTime);
-                                setTimeout(updateOrJump, 1000);
-                            } else {
-                                window.location = '/';
+                            const elem = document.getElementById('countdown');
+                            const updateOrJump = () => {
+                                let curTime = Number(elem.innerText);
+                                if (curTime > 0) {
+                                    curTime--;
+                                    elem.innerText = String(curTime);
+                                    setTimeout(updateOrJump, 1000);
+                                } else {
+                                    window.location = '/';
+                                }
                             }
-                        }
-                        window.onload = () => updateOrJump();
+                            window.onload = () => updateOrJump();
                         </script>
-                        </body>
+                    </body>
                     </html>
                     """
 
